@@ -184,7 +184,7 @@ q_glm <- function(formula = ~ A*.,
   q_glm <- new_q_model(q_glm)
   return(q_glm)
 }
-
+#' @export
 predict.q_glm <- function(object, new_AH, ...){
   model <- getElement(object, "model")
   pred <- predict(model, newdata = new_AH, type = "response")
@@ -234,7 +234,7 @@ q_glmnet <- function(formula = ~ A*.,
   q_glmnet <- new_q_model(q_glmnet)
   return(q_glmnet)
 }
-
+#' @export
 predict.q_glmnet <- function(object, new_AH, ...) {
   design <- getElement(object, "design")
   model <- getElement(object, "model")
@@ -260,7 +260,7 @@ perf_ranger <- function(fit, data,  ...) {
 #' @export
 q_rf <- function(formula = ~.,
                  num.trees=c(250, 500, 750), mtry=NULL,
-                 cv_args=list(K=3, rep=1), ...) {
+                 cv_args=list(nfolds=3, rep=1), ...) {
   if (!requireNamespace("ranger")) stop("Package 'ranger' required.")
   formula <- as.formula(formula)
   dotdotdot <- list(...)
@@ -282,7 +282,7 @@ q_rf <- function(formula = ~.,
     res <- NULL; best <- 1
     if (length(ml)>1) {
       res <- tryCatch(targeted::cv(ml, data=data, perf=perf_ranger,
-                               K=cv_args$K, rep=cv_args$rep),
+                               nfolds=cv_args$nfolds, rep=cv_args$rep),
                       error=function(...) NULL)
       best <- if (is.null(res)) 1 else which.min(summary(res))
     }
@@ -305,7 +305,7 @@ q_rf <- function(formula = ~.,
   q_rf <- new_q_model(q_rf)
   return(q_rf)
 }
-
+#' @export
 predict.q_rf <- function(object, new_AH, ...) {
   model <- getElement(object, "model")
   design <- getElement(object, "design")
@@ -379,7 +379,7 @@ q_sl <- function(formula = ~ .,
   q_sl <- new_q_model(q_sl)
   return(q_sl)
 }
-
+#' @export
 predict.q_sl <- function(object, new_AH, ...) {
   model <- getElement(object, "model")
   design <- getElement(object, "design")
@@ -403,7 +403,7 @@ q_xgboost <- function(formula = ~.,
                       max_depth = 6,
                       eta = 0.3,
                       nthread = 1,
-                      cv_args=list(K=3, rep=1)) {
+                      cv_args=list(nfolds=3, rep=1)) {
   if (!requireNamespace("xgboost")) stop("Package 'xgboost' required")
   formula <- as.formula(formula)
   environment(formula) <- NULL
@@ -413,7 +413,7 @@ q_xgboost <- function(formula = ~.,
                  eta, nthread){
     targeted::ml_model$new(formula,
                            info = "xgBoost",
-                           fit = function(x, y) {
+                           estimate = function(x, y) {
                              xgboost::xgboost(
                                data = x, label = y,
                                objective = objective,
@@ -452,7 +452,7 @@ q_xgboost <- function(formula = ~.,
 
     cv_res <- NULL
     if (length(ml_models)>1){
-      cv_res <- tryCatch(targeted::cv(ml_models, data, K=cv_args$K, rep = cv_args$rep),
+      cv_res <- tryCatch(targeted::cv(ml_models, data, nfolds=cv_args$nfolds, rep = cv_args$rep),
                          error = function(e) e)
       if (inherits(cv_res, "error")) {
         cv_res$message <-
@@ -490,7 +490,7 @@ q_xgboost <- function(formula = ~.,
 
   return(q)
 }
-
+#' @export
 predict.q_xgboost <- function(object, new_AH, ...){
   model <- getElement(object, "model")
   design <- getElement(object, "design")
